==> haskell-split-0.2.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-split/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3
id: split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
key: split_CDzOynTh4l8Ahg1HaWUL4Z
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/split-0.2.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/split-0.2.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/split-0.2.3
hs-libraries: HSsplit-0.2.3-CDzOynTh4l8Ahg1HaWUL4Z
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-split/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.1
id: split-0.2.3.1-720861915f5bd1738e9c1363195cfb8f
key: split_2IxbOPGrTSq7kFrJA7odmE
license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/split-0.2.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/split-0.2.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/split-0.2.3.1
hs-libraries: HSsplit-0.2.3.1-2IxbOPGrTSq7kFrJA7odmE
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
